==> form-dinamico-react-render-0.5.10.tgz: package/README.md <==
# form-dinamico-react-render

## react-jsonschema-form
Foi realizado um fork do componente principal para adicionar a funcionalidade de Grid Layout.

O fork encontra-se no [github](https://github.com/santosguilherme/react-jsonschema-form)

### Alterando
Para realizar uma alteração e gerar versão, executar os passos:
1. Clonar o repositório no [github](https://github.com/santosguilherme/react-jsonschema-form)
2. Alterar o atributo **name** do arquivo `package.json` para **react-jsonschema-form-ungp**
3. Verificar a ultima versão publicada na [página do npm](https://www.npmjs.com/package/react-jsonschema-form-ungp) e alterar para a nova versão
4. Rodar o comando `npm run build` para gerar versão da biblioteca
5. Rodar o comando `npm login`:

6. `npm publish` irá publicar o componente no [repositório global do npm](https://docs.npmjs.com/misc/registry).

## Gerar versão
1. `npm run build` irá construir o componente para ser publicado.

2. Rodar o comando `npm login`:

3. `npm publish` irá publicar o componente no [repositório global do npm](https://docs.npmjs.com/misc/registry).

## Instalar and rodar localmente
* Running `npm install` in the components's root directory will install everything you need for development.
* `npm start` will run a development server with the component's demo app at [http://localhost:3000](http://localhost:3000) with hot module reloading.

## nwb
This project was bootstrapped with [nwb toolkit](https://github.com/insin/nwb). You can find more information on how to perform common tasks [here](https://github.com/insin/nwb/blob/master/README.md).

==> form-dinamico-react-render-0.8.3.tgz: package/README.md <==
# form-dinamico-react-render

## react-jsonschema-form
Foi realizado um fork do componente principal para adicionar a funcionalidade de Grid Layout.

O fork encontra-se no [github](https://github.com/santosguilherme/react-jsonschema-form)

### Alterando
Para realizar uma alteração e gerar versão, executar os passos:
1. Clonar o repositório no [github](https://github.com/santosguilherme/react-jsonschema-form)
2. Alterar o atributo **name** do arquivo `package.json` para **react-jsonschema-form-ungp**
3. Verificar a ultima versão publicada na [página do npm](https://www.npmjs.com/package/react-jsonschema-form-ungp) e alterar para a nova versão
4. Rodar o comando `npm run build` para gerar versão da biblioteca
5. Rodar o comando `npm login`:

6. `npm publish` irá publicar o componente no [repositório global do npm](https://docs.npmjs.com/misc/registry).

## Gerar versão
1. `npm run build` irá construir o componente para ser publicado.

2. Rodar o comando `npm login` com os parâmetros de credentials.

3. `npm publish` irá publicar o componente no [repositório global do npm](https://docs.npmjs.com/misc/registry).

## Instalar and rodar localmente
* Running `npm install` in the components's root directory will install everything you need for development.
* `npm start` will run a development server with the component's demo app at [http://localhost:3000](http://localhost:3000) with hot module reloading.

## nwb
This project was bootstrapped with [nwb toolkit](https://github.com/insin/nwb). You can find more information on how to perform common tasks [here](https://github.com/insin/nwb/blob/master/README.md).
